cliio

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 28, 2026 License: MIT Imports: 12 Imported by: 0

Documentation

Overview

Package cliio provides utilities for printing output to the terminal including support for pagers and colored output.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Printer

type Printer interface {
	SetOut(out io.Writer)
	SetErrOut(errOut io.Writer)
	SetPagerMode(mode string) error
	Print(str string)
	PrintError(err error)
	PrintTime(time time.Duration)
	PrintViaPager(str string)
}

Printer defines terminal output behavior for regular, error, timed, and pager output.

func NewPgxPrinter

func NewPgxPrinter(out io.Writer, errOut io.Writer) Printer

NewPgxPrinter creates a printer with pager auto-detection.

Jump to