Documentation
¶
Overview ¶
Package cliio provides utilities for printing output to the terminal including support for pagers and colored output.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Printer ¶
type Printer interface {
SetOut(out io.Writer)
SetErrOut(errOut io.Writer)
SetPagerMode(mode string) error
Print(str string)
PrintError(err error)
PrintTime(time time.Duration)
PrintViaPager(str string)
}
Printer defines terminal output behavior for regular, error, timed, and pager output.
Click to show internal directories.
Click to hide internal directories.